$hg16
-
+
-
+
diff --git a/tools/data_source/microbial_import.py b/tools/data_source/microbial_import.py
index 735eed94929..fb8fc26723c 100644
--- a/tools/data_source/microbial_import.py
+++ b/tools/data_source/microbial_import.py
@@ -24,7 +24,8 @@ while have_none:
#create dictionary keyed by uid of tuples of (displayName,filePath,build) for all files
available_files = {}
try:
- for line in open( "/depot/data2/galaxy/microbes/microbial_data.loc" ):
+ filename = "%s/microbial_data.loc" % os.environ.get( 'GALAXY_DATA_INDEX_DIR' )
+ for i, line in enumerate( file( filename ) ):
if not line or line[0:1] == "#" : continue
fields = line.split('\t')
try:
diff --git a/tools/data_source/microbial_import.xml b/tools/data_source/microbial_import.xml
index 5e616fd45b9..8534f8079bb 100644
--- a/tools/data_source/microbial_import.xml
+++ b/tools/data_source/microbial_import.xml
@@ -6,7 +6,7 @@
Select the Desired Kingdom
$kingdom
-
+
@@ -14,7 +14,7 @@
Select the Desired Organism
$org
-
+
@@ -30,49 +30,49 @@
Select Desired Glimmer3 Annotations
$Glimmer3
-
+
-
+
-
+
-
+
-
+
-
+
-
+
diff --git a/tools/data_source/microbial_import_code.py b/tools/data_source/microbial_import_code.py
index 6706396f206..1e99ec669ea 100644
--- a/tools/data_source/microbial_import_code.py
+++ b/tools/data_source/microbial_import_code.py
@@ -4,7 +4,9 @@ def load_microbial_data( sep='\t' ):
# set data.name in exec_after_process().
microbe_info= {}
orgs = {}
- for line in open( "/depot/data2/galaxy/microbes/microbial_data.loc" ):
+
+ filename = "%s/microbial_data.loc" % os.environ.get( 'GALAXY_DATA_INDEX_DIR' )
+ for i, line in enumerate( file( filename ) ):
line = line.rstrip( '\r\n' )
if line and not line.startswith( '#' ):
fields = line.split( sep )
diff --git a/tools/encode/random_intervals.xml b/tools/encode/random_intervals.xml
index b919c414a04..620cd90c4ac 100644
--- a/tools/encode/random_intervals.xml
+++ b/tools/encode/random_intervals.xml
@@ -16,7 +16,7 @@
-
+
diff --git a/tools/encode/random_intervals_no_bits.py b/tools/encode/random_intervals_no_bits.py
index c6aea8a2c61..4c07f68124f 100644
--- a/tools/encode/random_intervals_no_bits.py
+++ b/tools/encode/random_intervals_no_bits.py
@@ -106,7 +106,7 @@ def main():
use_mask = sys.argv[11]
overlaps = sys.argv[12]
available_regions = {}
- loc_file = "/depot/data2/galaxy/regions.loc"
+ loc_file = "%s/regions.loc" % os.environ.get( 'GALAXY_DATA_INDEX_DIR' )
for i, line in enumerate( file( loc_file ) ):
line = line.rstrip( '\r\n' )
diff --git a/tools/extract/extractAxt_wrapper.xml b/tools/extract/extractAxt_wrapper.xml
index d800ca72245..10ba5edf2b4 100644
--- a/tools/extract/extractAxt_wrapper.xml
+++ b/tools/extract/extractAxt_wrapper.xml
@@ -5,7 +5,7 @@
-
+
diff --git a/tools/extract/extract_genomic_dna.py b/tools/extract/extract_genomic_dna.py
index 816343ee3a1..9eae9414de6 100644
--- a/tools/extract/extract_genomic_dna.py
+++ b/tools/extract/extract_genomic_dna.py
@@ -10,8 +10,8 @@ from bx.cookbook import doc_optparse
import bx.seq.nib
import bx.seq.twobit
-nib_file = "/depot/data2/galaxy/alignseq.loc"
-twobit_file = "/depot/data2/galaxy/twobit.loc"
+nib_file = "%s/alignseq.loc" % os.environ.get( 'GALAXY_DATA_INDEX_DIR' )
+twobit_file = "%s/twobit.loc" % os.environ.get( 'GALAXY_DATA_INDEX_DIR' )
def stop_err( msg ):
sys.stderr.write( msg )
diff --git a/tools/extract/extract_genomic_dna.xml b/tools/extract/extract_genomic_dna.xml
index 13b1d569318..465038be13c 100644
--- a/tools/extract/extract_genomic_dna.xml
+++ b/tools/extract/extract_genomic_dna.xml
@@ -3,7 +3,8 @@
extract_genomic_dna.py $input $out_file1 $input_chromCol $input_startCol $input_endCol $input_strandCol $dbkey $out_format
-
+
+
diff --git a/tools/extract/liftOver_wrapper.py b/tools/extract/liftOver_wrapper.py
index 94117835a65..142f56d932f 100644
--- a/tools/extract/liftOver_wrapper.py
+++ b/tools/extract/liftOver_wrapper.py
@@ -21,7 +21,7 @@ mapfilepath = sys.argv[5]
#ensure dbkey is set
if in_dbkey == "?":
- stop_err( "Input dataset genome build unspecified, click the pencil icon in hte history item to specify it." )
+ stop_err( "Input dataset genome build unspecified, click the pencil icon in the history item to specify it." )
cmd_line = "liftOver " + infile + " " + mapfilepath + " " + outfile1 + " " + outfile2 + " > /dev/null 2>&1"
diff --git a/tools/extract/liftOver_wrapper.xml b/tools/extract/liftOver_wrapper.xml
index 4d0df852098..be28b2e90a2 100644
--- a/tools/extract/liftOver_wrapper.xml
+++ b/tools/extract/liftOver_wrapper.xml
@@ -6,7 +6,7 @@
-
+
diff --git a/tools/extract/phastOdds/phastOdds_tool.xml b/tools/extract/phastOdds/phastOdds_tool.xml
index aba6314324f..25dc09e9cbc 100644
--- a/tools/extract/phastOdds/phastOdds_tool.xml
+++ b/tools/extract/phastOdds/phastOdds_tool.xml
@@ -6,7 +6,7 @@
-
+
diff --git a/tools/filters/axt_to_lav.xml b/tools/filters/axt_to_lav.xml
index 747cca001f4..2019667362b 100644
--- a/tools/filters/axt_to_lav.xml
+++ b/tools/filters/axt_to_lav.xml
@@ -1,7 +1,7 @@
Converts an AXT formated file to LAV format
- axt_to_lav.py /depot/data2/galaxy/$dbkey_1/seq/%s.nib:$dbkey_1:./static/ucsc/chrom/${dbkey_1}.len /depot/data2/galaxy/$dbkey_2/seq/%s.nib:$dbkey_2:./static/ucsc/chrom/${dbkey_2}.len $align_input $lav_file $seq_file1 $seq_file2
+ axt_to_lav.py ${GALAXY_DATA_INDEX_DIR}/$dbkey_1/seq/%s.nib:$dbkey_1:./static/ucsc/chrom/${dbkey_1}.len ${GALAXY_DATA_INDEX_DIR}/$dbkey_2/seq/%s.nib:$dbkey_2:./static/ucsc/chrom/${dbkey_2}.len $align_input $lav_file $seq_file1 $seq_file2
diff --git a/tools/maf/genebed_maf_to_fasta.xml b/tools/maf/genebed_maf_to_fasta.xml
index 61a56313b27..ee67d245c23 100644
--- a/tools/maf/genebed_maf_to_fasta.xml
+++ b/tools/maf/genebed_maf_to_fasta.xml
@@ -26,13 +26,13 @@
-
+
-
+
diff --git a/tools/maf/interval2maf.xml b/tools/maf/interval2maf.xml
index 8d1dbd30cc1..a22c50bc79d 100644
--- a/tools/maf/interval2maf.xml
+++ b/tools/maf/interval2maf.xml
@@ -21,7 +21,7 @@
-
+
diff --git a/tools/maf/interval2maf_pairwise.xml b/tools/maf/interval2maf_pairwise.xml
index 83277e5e5e6..d46c4c01e6c 100644
--- a/tools/maf/interval2maf_pairwise.xml
+++ b/tools/maf/interval2maf_pairwise.xml
@@ -1,12 +1,12 @@
given a set of genomic intervals
- interval2maf.py --dbkey=$input1_dbkey --chromCol=$input1_chromCol --startCol=$input1_startCol --endCol=$input1_endCol --strandCol=$input1_strandCol --mafType=$mafType --interval_file=$input1 --output_file=$out_file1 --indexLocation=/depot/data2/galaxy/maf_pairwise.loc
+ interval2maf.py --dbkey=$input1_dbkey --chromCol=$input1_chromCol --startCol=$input1_startCol --endCol=$input1_endCol --strandCol=$input1_strandCol --mafType=$mafType --interval_file=$input1 --output_file=$out_file1 --indexLocation=${GALAXY_DATA_INDEX_DIR}/maf_pairwise.loc
-
+
diff --git a/tools/maf/interval_maf_to_merged_fasta.xml b/tools/maf/interval_maf_to_merged_fasta.xml
index 7aac378c709..8c12799608c 100644
--- a/tools/maf/interval_maf_to_merged_fasta.xml
+++ b/tools/maf/interval_maf_to_merged_fasta.xml
@@ -27,13 +27,13 @@
-
+
-
+
diff --git a/tools/maf/maf_stats.xml b/tools/maf/maf_stats.xml
index 21b50909cc3..2150332838a 100644
--- a/tools/maf/maf_stats.xml
+++ b/tools/maf/maf_stats.xml
@@ -24,7 +24,7 @@
-
+
diff --git a/tools/maf/maf_stats_code.py b/tools/maf/maf_stats_code.py
index 2a6c233d322..7254187e07f 100644
--- a/tools/maf/maf_stats_code.py
+++ b/tools/maf/maf_stats_code.py
@@ -1,9 +1,11 @@
+import os
def load_maf_data( sep='\t' ):
# FIXME: this function is duplicated in the DynamicOptions class. It is used here only to
# set data.name in exec_before_job().
maf_sets = {}
- for line in open( "/depot/data2/galaxy/maf_index.loc" ):
+ filename = "%s/maf_index.loc" % os.environ.get( 'GALAXY_DATA_INDEX_DIR' )
+ for i, line in enumerate( file( filename ) ):
line = line.rstrip( '\r\n' )
if line and not line.startswith( '#' ):
fields = line.split( sep )
diff --git a/tools/metag_tools/blat_wrapper.py b/tools/metag_tools/blat_wrapper.py
index bbf301bb2a5..7996c8f2a50 100644
--- a/tools/metag_tools/blat_wrapper.py
+++ b/tools/metag_tools/blat_wrapper.py
@@ -2,13 +2,13 @@
import os, sys, tempfile
-nib_file = "/depot/data2/galaxy/alignseq.loc"
-twobit_file = "/depot/data2/galaxy/twobit.loc"
+nib_file = "%s/alignseq.loc" % os.environ.get( 'GALAXY_DATA_INDEX_DIR' )
+twobit_file = "/%s/twobit.loc" % os.environ.get( 'GALAXY_DATA_INDEX_DIR' )
def check_nib_file( dbkey ):
nib_path = ''
nibs = {}
- for line in open( nib_file ):
+ for i, line in enumerate( file( nib_file ) ):
line = line.rstrip( '\r\n' )
if line and not line.startswith( "#" ):
fields = line.split()
@@ -23,7 +23,7 @@ def check_nib_file( dbkey ):
def check_twobit_file( dbkey ):
twobit_path = ''
twobits = {}
- for line in open( twobit_file ):
+ for i, line in enumerate( file( twobit_file ) ):
line = line.rstrip( '\r\n' )
if line and not line.startswith( "#" ):
fields = line.split()
diff --git a/tools/metag_tools/megablast_wrapper.py b/tools/metag_tools/megablast_wrapper.py
index fbe4eb4467f..6a0db3982c7 100644
--- a/tools/metag_tools/megablast_wrapper.py
+++ b/tools/metag_tools/megablast_wrapper.py
@@ -6,7 +6,7 @@ run megablast for metagenomics data
import sys, os, tempfile, subprocess
from megablast_xml_parser import *
-DB_LOC = "/depot/data2/galaxy/blastdb.loc"
+DB_LOC = "%s/blastdb.loc" % os.environ.get( 'GALAXY_DATA_INDEX_DIR' )
def __main__():
# file I/O
diff --git a/tools/regVariation/quality_filter.xml b/tools/regVariation/quality_filter.xml
index b99ffe672c6..b0401dbc91f 100644
--- a/tools/regVariation/quality_filter.xml
+++ b/tools/regVariation/quality_filter.xml
@@ -16,7 +16,7 @@
#else
${mask_region.length}
#end if
- "/depot/data2/galaxy/quality_scores.loc"
+ ${GALAXY_DATA_INDEX_DIR}/quality_scores.loc
diff --git a/tools/stats/aggregate_binned_scores_in_intervals.xml b/tools/stats/aggregate_binned_scores_in_intervals.xml
index 3bab4584b09..8761b477828 100644
--- a/tools/stats/aggregate_binned_scores_in_intervals.xml
+++ b/tools/stats/aggregate_binned_scores_in_intervals.xml
@@ -16,7 +16,7 @@
-
+
diff --git a/tools/extract/extractAxt_wrapper.pl b/tools/extract/extractAxt_wrapper.pl
index f83bf7f2d98..e910293301a 100644
--- a/tools/extract/extractAxt_wrapper.pl
+++ b/tools/extract/extractAxt_wrapper.pl
@@ -5,7 +5,7 @@
# directory of universe's tools section
# Takes the following parameters:
# extractorAxt_wrapper.pl -i $inp_file1 -o $out_file1 --species $species -g $dbkey $chroCol $startCol $endCol $strandCol
# Location of alignment files is taken from /depot/data2/galaxy/alignseq.loc (to change -> edit line 19)
use strict;
use warnings;
@@ -16,7 +16,7 @@ die "Your query genome, $ARGV[7], is the same as your target genome, $ARGV[5]. P
die "Not enough params -> check\n" unless @ARGV == 12;
-my $alignseqLoc = "/depot/data2/galaxy/alignseq.loc";
+my $alignseqLoc = "$GALAXY_DATA_INDEX_DIR/alignseq.loc";
my %alignLocation = ();
my @locFields = ();
my $extractAxtStatus = 0;
@@ -5,7 +5,7 @@
# Takes the following parameters:
# extractorAxt_wrapper.pl -i $inp_file1 -o $out_file1 --species $species -g $dbkey $chroCol $startCol $endCol $strandCol
-# Location of alignment files is taken from /depot/data2/galaxy/alignseq.loc (to change -> edit line 19)
+# Location of alignment files is taken from $GALAXY_DATA_INDEX_DIR/alignseq.loc (to change -> edit line 19)
use strict;
use warnings;